@@ -4,27 +4,26 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include <QMutex>
 #include <QObject>
 #include <QTest>
 #include <QTimer>
-#include <QMutex>
 
-#include "storage/itemretriever.h"
+#include "commandcontext.h"
+#include "storage/datastore.h"
 #include "storage/itemretrievaljob.h"
 #include "storage/itemretrievalmanager.h"
 #include "storage/itemretrievalrequest.h"
-#include "storage/datastore.h"
-#include "commandcontext.h"
+#include "storage/itemretriever.h"
 
-#include "fakeakonadiserver.h"
 #include "dbinitializer.h"
+#include "fakeakonadiserver.h"
 
 #include <aktest.h>
 
 using namespace Akonadi::Server;
 
-struct JobResult
-{
+struct JobResult {
     qint64 pimItemId;
     QByteArray partname;
     QByteArray partdata;
@@ -35,8 +34,7 @@ class FakeItemRetrievalJob : public AbstractItemRetrievalJob
 {
     Q_OBJECT
 public:
-    FakeItemRetrievalJob(ItemRetrievalRequest req, DbInitializer &dbInitializer,
-                         const QVector<JobResult> &results, QObject *parent)
+    FakeItemRetrievalJob(ItemRetrievalRequest req, DbInitializer &dbInitializer, const QVector<JobResult> &results, QObject *parent)
         : AbstractItemRetrievalJob(std::move(req), parent)
         , mDbInitializer(dbInitializer)
         , mResults(results)
@@ -51,10 +49,9 @@ public:
                 const PimItem item = PimItem::retrieveById(res.pimItemId);
                 const auto parts = item.parts();
                 // Try to find the part by name
-                auto it = std::find_if(parts.begin(), parts.end(),
-                                       [res](const Part &part) {
-                                           return part.partType().name().toLatin1() == res.partname;
-                                       });
+                auto it = std::find_if(parts.begin(), parts.end(), [res](const Part &part) {
+                    return part.partType().name().toLatin1() == res.partname;
+                });
                 if (it == parts.end()) {
                     // Does not exist, create it
                     mDbInitializer.createPart(res.pimItemId, "PLD:" + res.partname, res.partdata);
@@ -98,12 +95,12 @@ public:
 
     void addJobResult(qint64 itemId, const QByteArray &partname, const QByteArray &partdata)
     {
-        mJobResults.insert(itemId, JobResult{ itemId, partname, partdata, QString() });
+        mJobResults.insert(itemId, JobResult{itemId, partname, partdata, QString()});
     }
 
     void addJobResult(qint64 itemId, const QString &error)
     {
-        mJobResults.insert(itemId, JobResult{ itemId, QByteArray(), QByteArray(), error });
+        mJobResults.insert(itemId, JobResult{itemId, QByteArray(), QByteArray(), error});
     }
 
     AbstractItemRetrievalJob *retrievalJob(ItemRetrievalRequest request, QObject *parent) override
@@ -140,8 +137,11 @@ class ClientThread : public QThread
 {
 public:
     ClientThread(Entity::Id itemId, const RequestedParts &requestedParts, ItemRetrievalManager &manager)
-        : m_itemId(itemId), m_requestedParts(requestedParts), m_manager(manager)
-    {}
+        : m_itemId(itemId)
+        , m_requestedParts(requestedParts)
+        , m_manager(manager)
+    {
+    }
 
     void run() override
     {
@@ -164,13 +164,13 @@ public:
         DataStore::self()->close();
     }
 
-    struct Results
-    {
+    struct Results {
         bool success;
         int signalsCount;
         QVector<qint64> emittedItems;
     };
-    Results results() const {
+    Results results() const
+    {
         QMutexLocker lock(&m_mutex);
         return m_results;
     }
@@ -188,11 +188,11 @@ class ItemRetrieverTest : public QObject
 {
     Q_OBJECT
 
-
     using ExistingParts = QVector<QPair<QByteArray /* name */, QByteArray /* data */>>;
     using AvailableParts = QVector<QPair<QByteArray /* name */, QByteArray /* data */>>;
 
     FakeAkonadiServer mAkonadi;
+
 public:
     ItemRetrieverTest()
     {
@@ -208,8 +208,8 @@ private Q_SLOTS:
         ItemRetriever r1(mAkonadi.itemRetrievalManager(), nullptr, context);
         r1.setRetrieveFullPayload(true);
         QCOMPARE(r1.retrieveParts().size(), 1);
-        QCOMPARE(r1.retrieveParts().at(0), { "PLD:RFC822" });
-        r1.setRetrieveParts({ "PLD:FOO" });
+        QCOMPARE(r1.retrieveParts().at(0), {"PLD:RFC822"});
+        r1.setRetrieveParts({"PLD:FOO"});
         QCOMPARE(r1.retrieveParts().size(), 2);
     }
 
@@ -223,52 +223,29 @@ private Q_SLOTS:
         QTest::addColumn<int>("expectedParts");
 
         QTest::newRow("should retrieve missing payload part")
-            << ExistingParts()
-            << AvailableParts{ { "RFC822", "somedata" } }
-            << RequestedParts{ "PLD:RFC822" }
-            << 1 << 1 << 1;
+            << ExistingParts() << AvailableParts{{"RFC822", "somedata"}} << RequestedParts{"PLD:RFC822"} << 1 << 1 << 1;
 
         QTest::newRow("should retrieve multiple missing payload parts")
-            << ExistingParts()
-            << AvailableParts{ { "RFC822", "somedata" }, { "HEAD", "head" } }
-            << RequestedParts{ "PLD:HEAD", "PLD:RFC822" }
-            << 1 << 1 << 2;
+            << ExistingParts() << AvailableParts{{"RFC822", "somedata"}, {"HEAD", "head"}} << RequestedParts{"PLD:HEAD", "PLD:RFC822"} << 1 << 1 << 2;
 
         QTest::newRow("should not retrieve existing payload part")
-            << ExistingParts{ { "PLD:RFC822", "somedata" } }
-            << AvailableParts()
-            << RequestedParts{ "PLD:RFC822" }
-            << 0 << 1 << 1;
+            << ExistingParts{{"PLD:RFC822", "somedata"}} << AvailableParts() << RequestedParts{"PLD:RFC822"} << 0 << 1 << 1;
 
         QTest::newRow("should not retrieve multiple existing payload parts")
-            << ExistingParts{ { "PLD:RFC822", "somedata" }, { "PLD:HEAD", "head" } }
-            << AvailableParts()
-            << RequestedParts{ "PLD:RFC822", "PLD:HEAD" }
-            << 0 << 1 << 2;
+            << ExistingParts{{"PLD:RFC822", "somedata"}, {"PLD:HEAD", "head"}} << AvailableParts() << RequestedParts{"PLD:RFC822", "PLD:HEAD"} << 0 << 1 << 2;
 
         QTest::newRow("should retrieve missing but not existing payload part")
-            << ExistingParts{ { "PLD:HEAD", "head" } }
-            << AvailableParts{ { "RFC822", "somedata" } }
-            << RequestedParts{ "PLD:HEAD", "PLD:RFC822" }
-            << 1 << 1 << 2;
+            << ExistingParts{{"PLD:HEAD", "head"}} << AvailableParts{{"RFC822", "somedata"}} << RequestedParts{"PLD:HEAD", "PLD:RFC822"} << 1 << 1 << 2;
 
         QTest::newRow("should retrieve expired payload part")
-            << ExistingParts{ { "PLD:RFC822", QByteArray() } }
-            << AvailableParts{ { "RFC822", "somedata" } }
-            << RequestedParts{ "PLD:RFc822" }
-            << 1 << 1 << 1;
+            << ExistingParts{{"PLD:RFC822", QByteArray()}} << AvailableParts{{"RFC822", "somedata"}} << RequestedParts{"PLD:RFc822"} << 1 << 1 << 1;
 
         QTest::newRow("should not retrieve one out of multiple existing payload parts")
-            << ExistingParts{ { "PLD:RFC822", "somedata" }, { "PLD:HEAD", "head" }, { "PLD:ENVELOPE", "envelope" } }
-            << AvailableParts()
-            << RequestedParts{ "PLD:RFC822", "PLD:HEAD" }
-            << 0 << 1 << 3;
+            << ExistingParts{{"PLD:RFC822", "somedata"}, {"PLD:HEAD", "head"}, {"PLD:ENVELOPE", "envelope"}} << AvailableParts()
+            << RequestedParts{"PLD:RFC822", "PLD:HEAD"} << 0 << 1 << 3;
 
         QTest::newRow("should retrieve missing payload part and ignore attributes")
-            << ExistingParts{ { "ATR:MYATTR", "myattrdata" } }
-            << AvailableParts{ { "RFC822", "somedata" } }
-            << RequestedParts{ "PLD:RFC822" }
-            << 1 << 1 << 2;
+            << ExistingParts{{"ATR:MYATTR", "myattrdata"}} << AvailableParts{{"RFC822", "somedata"}} << RequestedParts{"PLD:RFC822"} << 1 << 1 << 2;
     }
 
     void testRetrieval()
@@ -280,11 +257,10 @@ private Q_SLOTS:
         QFETCH(int, expectedSignals);
         QFETCH(int, expectedParts);
 
-
         // Setup
         for (int step = 0; step < 2; ++step) {
             DbInitializer dbInitializer;
-            auto *factory = new FakeItemRetrievalJobFactory(dbInitializer);
+            auto factory = new FakeItemRetrievalJobFactory(dbInitializer);
             ItemRetrievalManager mgr{std::unique_ptr<AbstractItemRetrievalJobFactory>(factory)};
             QTest::qWait(100);
 
@@ -313,7 +289,7 @@ private Q_SLOTS:
                 QCOMPARE(results.signalsCount, expectedSignals);
                 // ... with that one item
                 if (expectedSignals > 0) {
-                    QCOMPARE(results.emittedItems, QVector<qint64>{ item.id() });
+                    QCOMPARE(results.emittedItems, QVector<qint64>{item.id()});
                 }
 
                 // Check that the factory had exactly one retrieval job
@@ -335,7 +311,7 @@ private Q_SLOTS:
                     QVERIFY(results.success);
                     QCOMPARE(results.signalsCount, expectedSignals);
                     if (expectedSignals > 0) {
-                        QCOMPARE(results.emittedItems, QVector<qint64>{ item.id() });
+                        QCOMPARE(results.emittedItems, QVector<qint64>{item.id()});
                     }
                 }
                 qDeleteAll(threads);
@@ -350,15 +326,13 @@ private Q_SLOTS:
                     continue;
                 }
 
-                auto it = std::find_if(availableParts.constBegin(), availableParts.constEnd(),
-                        [dbPart](const QPair<QByteArray, QByteArray> &p) {
-                        return dbPart.partType().name().toLatin1() == p.first;
-                        });
+                auto it = std::find_if(availableParts.constBegin(), availableParts.constEnd(), [dbPart](const QPair<QByteArray, QByteArray> &p) {
+                    return dbPart.partType().name().toLatin1() == p.first;
+                });
                 if (it == availableParts.constEnd()) {
-                    it = std::find_if(existingParts.constBegin(), existingParts.constEnd(),
-                            [fqname](const QPair<QByteArray, QByteArray> &p) {
-                            return fqname.toLatin1() == p.first;
-                            });
+                    it = std::find_if(existingParts.constBegin(), existingParts.constEnd(), [fqname](const QPair<QByteArray, QByteArray> &p) {
+                        return fqname.toLatin1() == p.first;
+                    });
                     QVERIFY(it != existingParts.constEnd());
                 }
 
