@@ -7,7 +7,6 @@
 
 #include "resourcebase.h"
 #include "agentbase_p.h"
-#include <kio_version.h>
 
 #include "akonadifull-version.h"
 #include "collectiondeletejob.h"
@@ -188,15 +187,8 @@ public:
             }
             mItemSyncer->setDisableAutomaticDeliveryDone(mDisableAutomaticItemDeliveryDone);
             mItemSyncer->setProperty("collection", QVariant::fromValue(q->currentCollection()));
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 80, 0)
             connect(mItemSyncer, &KJob::percentChanged, this,
                     &ResourceBasePrivate::slotPercent); // NOLINT(google-runtime-int): ulong comes from KJob
-#else
-            connect(mItemSyncer,
-                    qOverload<KJob *, unsigned long>(&KJob::percent),
-                    this,
-                    &ResourceBasePrivate::slotPercent); // NOLINT(google-runtime-int): ulong comes from KJob
-#endif
 
             connect(mItemSyncer, &KJob::result, this, &ResourceBasePrivate::slotItemSyncDone);
             connect(mItemSyncer, &ItemSync::readyForNextBatch, q, &ResourceBase::retrieveNextItemSyncBatch);
@@ -557,7 +549,7 @@ QString ResourceBase::parseArguments(int argc, char **argv)
     // strip off full path and possible .exe suffix
     const QString catalog = fi.baseName();
 
-    auto translator = new QTranslator();
+    auto translator = new QTranslator(qApp);
     translator->load(catalog);
     QCoreApplication::installTranslator(translator);
 
@@ -641,7 +633,7 @@ void ResourceBasePrivate::slotDeleteResourceCollection()
 {
     Q_Q(ResourceBase);
 
-    CollectionFetchJob *job = new CollectionFetchJob(Collection::root(), CollectionFetchJob::FirstLevel);
+    auto job = new CollectionFetchJob(Collection::root(), CollectionFetchJob::FirstLevel);
     job->fetchScope().setResource(q->identifier());
     connect(job, &KJob::result, this, &ResourceBasePrivate::slotDeleteResourceCollectionDone);
 }
@@ -656,7 +648,7 @@ void ResourceBasePrivate::slotDeleteResourceCollectionDone(KJob *job)
         const auto fetchJob = static_cast<const CollectionFetchJob *>(job);
 
         if (!fetchJob->collections().isEmpty()) {
-            CollectionDeleteJob *job = new CollectionDeleteJob(fetchJob->collections().at(0));
+            auto job = new CollectionDeleteJob(fetchJob->collections().at(0));
             connect(job, &KJob::result, this, &ResourceBasePrivate::slotCollectionDeletionDone);
         } else {
             // there is no resource collection, so just ignore the request
@@ -767,15 +759,8 @@ void ResourceBase::collectionsRetrieved(const Collection::List &collections)
         d->mCollectionSyncer = new CollectionSync(identifier());
         d->mCollectionSyncer->setHierarchicalRemoteIds(d->mHierarchicalRid);
         d->mCollectionSyncer->setKeepLocalChanges(d->mKeepLocalCollectionChanges);
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 80, 0)
         connect(d->mCollectionSyncer, &KJob::percentChanged, d,
                 &ResourceBasePrivate::slotPercent); // NOLINT(google-runtime-int): ulong comes from KJob
-#else
-        connect(d->mCollectionSyncer,
-                qOverload<KJob *, unsigned long>(&KJob::percent),
-                d,
-                &ResourceBasePrivate::slotPercent); // NOLINT(google-runtime-int): ulong comes from KJob
-#endif
         connect(d->mCollectionSyncer, &KJob::result, d, &ResourceBasePrivate::slotCollectionSyncDone);
     }
     d->mCollectionSyncer->setRemoteCollections(collections);
@@ -791,15 +776,8 @@ void ResourceBase::collectionsRetrievedIncremental(const Collection::List &chang
         d->mCollectionSyncer = new CollectionSync(identifier());
         d->mCollectionSyncer->setHierarchicalRemoteIds(d->mHierarchicalRid);
         d->mCollectionSyncer->setKeepLocalChanges(d->mKeepLocalCollectionChanges);
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 80, 0)
         connect(d->mCollectionSyncer, &KJob::percentChanged, d,
                 &ResourceBasePrivate::slotPercent); // NOLINT(google-runtime-int): ulong comes from KJob
-#else
-        connect(d->mCollectionSyncer,
-                qOverload<KJob *, unsigned long>(&KJob::percent),
-                d,
-                &ResourceBasePrivate::slotPercent); // NOLINT(google-runtime-int): ulong comes from KJob
-#endif
         connect(d->mCollectionSyncer, &KJob::result, d, &ResourceBasePrivate::slotCollectionSyncDone);
     }
     d->mCollectionSyncer->setRemoteCollections(changedCollections, removedCollections);
@@ -814,15 +792,8 @@ void ResourceBase::setCollectionStreamingEnabled(bool enable)
     if (!d->mCollectionSyncer) {
         d->mCollectionSyncer = new CollectionSync(identifier());
         d->mCollectionSyncer->setHierarchicalRemoteIds(d->mHierarchicalRid);
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 80, 0)
         connect(d->mCollectionSyncer, &KJob::percentChanged, d,
                 &ResourceBasePrivate::slotPercent); // NOLINT(google-runtime-int): ulong comes from KJob
-#else
-        connect(d->mCollectionSyncer,
-                qOverload<KJob *, unsigned long>(&KJob::percent),
-                d,
-                &ResourceBasePrivate::slotPercent); // NOLINT(google-runtime-int): ulong comes from KJob
-#endif
         connect(d->mCollectionSyncer, &KJob::result, d, &ResourceBasePrivate::slotCollectionSyncDone);
     }
     d->mCollectionSyncer->setStreamingEnabled(enable);
@@ -860,7 +831,7 @@ void ResourceBasePrivate::slotCollectionSyncDone(KJob *job)
         }
     } else {
         if (scheduler->currentTask().type == ResourceScheduler::SyncAll) {
-            CollectionFetchJob *list = new CollectionFetchJob(Collection::root(), CollectionFetchJob::Recursive);
+            auto list = new CollectionFetchJob(Collection::root(), CollectionFetchJob::Recursive);
             list->setFetchScope(q->changeRecorder()->collectionFetchScope());
             list->fetchScope().fetchAttribute<SpecialCollectionAttribute>();
             list->fetchScope().fetchAttribute<FavoriteCollectionAttribute>();
@@ -922,7 +893,7 @@ void ResourceBasePrivate::slotLocalListDone(KJob *job)
     } else {
         Collection::List cols = static_cast<CollectionFetchJob *>(job)->collections();
         std::sort(cols.begin(), cols.end(), sortCollectionsForSync);
-        for (const Collection &col : qAsConst(cols)) {
+        for (const Collection &col : std::as_const(cols)) {
             scheduler->scheduleSync(col);
         }
         scheduler->scheduleFullSyncCompletion();
@@ -1275,7 +1246,7 @@ void ResourceBase::synchronizeCollection(qint64 collectionId)
 void ResourceBase::synchronizeCollection(qint64 collectionId, bool recursive)
 {
     Q_D(ResourceBase);
-    CollectionFetchJob *job = new CollectionFetchJob(Collection(collectionId), recursive ? CollectionFetchJob::Recursive : CollectionFetchJob::Base);
+    auto job = new CollectionFetchJob(Collection(collectionId), recursive ? CollectionFetchJob::Recursive : CollectionFetchJob::Base);
     job->setFetchScope(changeRecorder()->collectionFetchScope());
     job->fetchScope().setResource(identifier());
     job->fetchScope().setListFilter(CollectionFetchScope::Sync);
@@ -1309,7 +1280,7 @@ void ResourceBase::synchronizeCollectionAttributes(const Akonadi::Collection &co
 void ResourceBase::synchronizeCollectionAttributes(qint64 collectionId)
 {
     Q_D(ResourceBase);
-    CollectionFetchJob *job = new CollectionFetchJob(Collection(collectionId), CollectionFetchJob::Base);
+    auto job = new CollectionFetchJob(Collection(collectionId), CollectionFetchJob::Base);
     job->setFetchScope(changeRecorder()->collectionFetchScope());
     job->fetchScope().setResource(identifier());
     connect(job, &KJob::result, d, &ResourceBasePrivate::slotCollectionListForAttributesDone);
@@ -1410,7 +1381,7 @@ void ResourceBasePrivate::slotDelayedEmitProgress()
     if (mAutomaticProgressReporting) {
         Q_EMIT q->percent(mUnemittedProgress);
 
-        for (const QVariantMap &statusMap : qAsConst(mUnemittedAdvancedStatus)) {
+        for (const QVariantMap &statusMap : std::as_const(mUnemittedAdvancedStatus)) {
             Q_EMIT q->advancedStatus(statusMap);
         }
     }
@@ -1422,7 +1393,7 @@ void ResourceBasePrivate::slotPercent(KJob *job, quint64 percent)
 {
     mUnemittedProgress = static_cast<int>(percent);
 
-    const Collection collection = job->property("collection").value<Collection>();
+    const auto collection = job->property("collection").value<Collection>();
     if (collection.isValid()) {
         QVariantMap statusMap;
         statusMap.insert(QStringLiteral("key"), QStringLiteral("collectionSyncProgress"));
@@ -1573,15 +1544,8 @@ void ResourceBase::tagsRetrieved(const Tag::List &tags, const QHash<QString, Ite
                "Calling tagsRetrieved() although no tag retrieval is in progress");
     if (!d->mTagSyncer) {
         d->mTagSyncer = new TagSync(this);
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 80, 0)
         connect(d->mTagSyncer, &KJob::percentChanged, d,
                 &ResourceBasePrivate::slotPercent); // NOLINT(google-runtime-int): ulong comes from KJob
-#else
-        connect(d->mTagSyncer,
-                qOverload<KJob *, unsigned long>(&KJob::percent),
-                d,
-                &ResourceBasePrivate::slotPercent); // NOLINT(google-runtime-int): ulong comes from KJob
-#endif
         connect(d->mTagSyncer, &KJob::result, d, &ResourceBasePrivate::slotTagSyncDone);
     }
     d->mTagSyncer->setFullTagList(tags);
@@ -1611,15 +1575,8 @@ void ResourceBase::relationsRetrieved(const Relation::List &relations)
                "Calling relationsRetrieved() although no relation retrieval is in progress");
     if (!d->mRelationSyncer) {
         d->mRelationSyncer = new RelationSync(this);
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 80, 0)
         connect(d->mRelationSyncer, &KJob::percentChanged, d,
                 &ResourceBasePrivate::slotPercent); // NOLINT(google-runtime-int): ulong comes from KJob
-#else
-        connect(d->mRelationSyncer,
-                qOverload<KJob *, unsigned long>(&KJob::percent),
-                d,
-                &ResourceBasePrivate::slotPercent); // NOLINT(google-runtime-int): ulong comes from KJob
-#endif
         connect(d->mRelationSyncer, &KJob::result, d, &ResourceBasePrivate::slotRelationSyncDone);
     }
     d->mRelationSyncer->setRemoteRelations(relations);
