@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_COLLECTIONSYNC_P_H
-#define AKONADI_COLLECTIONSYNC_P_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "collection.h"
@@ -119,4 +118,3 @@ private:
 
 }
 
-#endif
