@@ -5,8 +5,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_ITEM_H
-#define AKONADI_ITEM_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "attribute.h"
@@ -104,22 +103,22 @@ public:
     /**
      * Describes the unique id type.
      */
-    typedef qint64 Id;
+    using Id = qint64;
 
     /**
      * Describes a list of items.
      */
-    typedef QVector<Item> List;
+    using List = QVector<Item>;
 
     /**
      * Describes a flag name.
      */
-    typedef QByteArray Flag;
+    using Flag = QByteArray;
 
     /**
      * Describes a set of flag names.
      */
-    typedef QSet<QByteArray> Flags;
+    using Flags = QSet<QByteArray>;
 
     /**
      * Describes the part name that is used to fetch the
@@ -565,30 +564,6 @@ public:
     template<typename T> void setPayload(const T &p);
     /// @cond PRIVATE
     template<typename T> void setPayload(T *p);
-
-// We know that auto_ptr is deprecated, but we still want to handle the case
-// without compilers yelling at us all the time just because item.h gets included
-// virtually everywhere
-#if __cplusplus < 201703L
-#ifdef __GNUC__
-#ifdef __clang__
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wdeprecated-declarations"
-#else
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-#endif
-#endif
-    template<typename T> void setPayload(std::auto_ptr<T> p);
-#ifdef __GNUC__
-#ifdef __clang__
-#pragma clang diagnostic pop
-#else
-#pragma GCC diagnostic pop
-#endif
-#endif
-#endif
-    template<typename T> void setPayload(std::unique_ptr<T> p);
     /// @endcond
 
     /**
@@ -796,11 +771,11 @@ template<typename T> T Item::payload() const
 
 template<typename T> typename std::enable_if<Internal::PayloadTrait<T>::isPolymorphic, T>::type Item::payloadImpl(const int *) const
 {
-    typedef Internal::PayloadTrait<T> PayloadType;
+    using PayloadType = Internal::PayloadTrait<T>;
     static_assert(PayloadType::isPolymorphic, "Non-polymorphic payload type in polymorphic implementation is not allowed");
 
-    typedef typename Internal::get_hierarchy_root<T>::type Root_T;
-    typedef Internal::PayloadTrait<Root_T> RootType;
+    using Root_T = typename Internal::get_hierarchy_root<T>::type;
+    using RootType = Internal::PayloadTrait<Root_T>;
     static_assert(!RootType::isPolymorphic,
                   "Root type of payload type must not be polymorphic"); // prevent endless recursion
 
@@ -809,7 +784,7 @@ template<typename T> typename std::enable_if<Internal::PayloadTrait<T>::isPolymo
 
 template<typename T> typename std::enable_if<!Internal::PayloadTrait<T>::isPolymorphic, T>::type Item::payloadImpl() const
 {
-    typedef Internal::PayloadTrait<T> PayloadType;
+    using PayloadType = Internal::PayloadTrait<T>;
     static_assert(!PayloadType::isPolymorphic, "Polymorphic payload type in non-polymorphic implementation is not allowed");
 
     const int metaTypeId = PayloadType::elementMetaTypeId();
@@ -834,8 +809,8 @@ template<typename T> typename std::enable_if<!Internal::PayloadTrait<T>::isPolym
 
 template<typename T, typename NewT> typename std::enable_if<!std::is_same<T, NewT>::value, bool>::type Item::tryToCloneImpl(T *ret, const int *) const
 {
-    typedef Internal::PayloadTrait<T> PayloadType;
-    typedef Internal::PayloadTrait<NewT> NewPayloadType;
+    using PayloadType = Internal::PayloadTrait<T>;
+    using NewPayloadType = Internal::PayloadTrait<NewT>;
 
     const int metaTypeId = PayloadType::elementMetaTypeId();
     Internal::PayloadBase *payloadBase = payloadBaseV2(NewPayloadType::sharedPointerId, metaTypeId);
@@ -864,7 +839,7 @@ template<typename T, typename NewT> typename std::enable_if<std::is_same<T, NewT
 
 template<typename T> typename std::enable_if<Internal::is_shared_pointer<T>::value, bool>::type Item::tryToClone(T *ret, const int *) const
 {
-    typedef Internal::PayloadTrait<T> PayloadType;
+    using PayloadType = Internal::PayloadTrait<T>;
     static_assert(!PayloadType::isPolymorphic, "Polymorphic payload type in non-polymorphic implementation is not allowed");
 
     return tryToCloneImpl<T, typename Internal::shared_pointer_traits<T>::next_shared_ptr>(ret);
@@ -872,7 +847,7 @@ template<typename T> typename std::enable_if<Internal::is_shared_pointer<T>::val
 
 template<typename T> typename std::enable_if<!Internal::is_shared_pointer<T>::value, bool>::type Item::tryToClone(T *) const
 {
-    typedef Internal::PayloadTrait<T> PayloadType;
+    using PayloadType = Internal::PayloadTrait<T>;
     static_assert(!PayloadType::isPolymorphic, "Polymorphic payload type in non-polymorphic implementation is not allowed");
 
     return false;
@@ -886,11 +861,11 @@ template<typename T> bool Item::hasPayload() const
 
 template<typename T> typename std::enable_if<Internal::PayloadTrait<T>::isPolymorphic, bool>::type Item::hasPayloadImpl(const int *) const
 {
-    typedef Internal::PayloadTrait<T> PayloadType;
+    using PayloadType = Internal::PayloadTrait<T>;
     static_assert(PayloadType::isPolymorphic, "Non-polymorphic payload type in polymorphic implementation is no allowed");
 
-    typedef typename Internal::get_hierarchy_root<T>::type Root_T;
-    typedef Internal::PayloadTrait<Root_T> RootType;
+    using Root_T = typename Internal::get_hierarchy_root<T>::type;
+    using RootType = Internal::PayloadTrait<Root_T>;
     static_assert(!RootType::isPolymorphic,
                   "Root type of payload type must not be polymorphic"); // prevent endless recursion
 
@@ -905,7 +880,7 @@ template<typename T> typename std::enable_if<Internal::PayloadTrait<T>::isPolymo
 
 template<typename T> typename std::enable_if<!Internal::PayloadTrait<T>::isPolymorphic, bool>::type Item::hasPayloadImpl() const
 {
-    typedef Internal::PayloadTrait<T> PayloadType;
+    using PayloadType = Internal::PayloadTrait<T>;
     static_assert(!PayloadType::isPolymorphic, "Polymorphic payload type in non-polymorphic implementation is not allowed");
 
     const int metaTypeId = PayloadType::elementMetaTypeId();
@@ -932,11 +907,11 @@ template<typename T> void Item::setPayload(const T &p)
 
 template<typename T> typename std::enable_if<Internal::PayloadTrait<T>::isPolymorphic>::type Item::setPayloadImpl(const T &p, const int *)
 {
-    typedef Internal::PayloadTrait<T> PayloadType;
+    using PayloadType = Internal::PayloadTrait<T>;
     static_assert(PayloadType::isPolymorphic, "Non-polymorphic payload type in polymorphic implementation is not allowed");
 
-    typedef typename Internal::get_hierarchy_root<T>::type Root_T;
-    typedef Internal::PayloadTrait<Root_T> RootType;
+    using Root_T = typename Internal::get_hierarchy_root<T>::type;
+    using RootType = Internal::PayloadTrait<Root_T>;
     static_assert(!RootType::isPolymorphic,
                   "Root type of payload type must not be polymorphic"); // prevent endless recursion
 
@@ -945,7 +920,7 @@ template<typename T> typename std::enable_if<Internal::PayloadTrait<T>::isPolymo
 
 template<typename T> typename std::enable_if<!Internal::PayloadTrait<T>::isPolymorphic>::type Item::setPayloadImpl(const T &p)
 {
-    typedef Internal::PayloadTrait<T> PayloadType;
+    using PayloadType = Internal::PayloadTrait<T>;
     std::unique_ptr<Internal::PayloadBase> pb(new Internal::Payload<T>(p));
     setPayloadBaseV2(PayloadType::sharedPointerId, PayloadType::elementMetaTypeId(), pb);
 }
@@ -955,37 +930,8 @@ template<typename T> void Item::setPayload(T *p)
     p->You_MUST_NOT_use_a_pointer_as_payload;
 }
 
-#if __cplusplus < 201703L
-#ifdef __GNUC__
-#ifdef __clang__
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wdeprecated-declarations"
-#else
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-#endif
-#endif
-template<typename T> void Item::setPayload(std::auto_ptr<T> p)
-{
-    p.Nice_try_but_a_std_auto_ptr_is_not_allowed_as_payload_either;
-}
-#ifdef __GNUC__
-#ifdef __clang__
-#pragma clang diagnostic pop
-#else
-#pragma GCC diagnostic pop
-#endif
-#endif
-#endif
-
-template<typename T> void Item::setPayload(std::unique_ptr<T> p)
-{
-    p.Nope_even_std_unique_ptr_is_not_allowed;
-}
-
 } // namespace Akonadi
 
 Q_DECLARE_METATYPE(Akonadi::Item)
 Q_DECLARE_METATYPE(Akonadi::Item::List)
 
-#endif
