@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_SUBSCRIPTIONMODEL_P_H
-#define AKONADI_SUBSCRIPTIONMODEL_P_H
+#pragma once
 
 #include "akonadicore_export.h"
 
@@ -76,4 +75,3 @@ private:
 
 }
 
-#endif
