@@ -5,54 +5,55 @@
  ***************************************************************************/
 
 #include "akonadi.h"
-#include "handler.h"
-#include "connection.h"
-#include "serveradaptor.h"
 #include "akonadiserver_debug.h"
+#include "connection.h"
+#include "handler.h"
+#include "serveradaptor.h"
 
+#include "aklocalserver.h"
 #include "cachecleaner.h"
-#include "intervalcheck.h"
-#include "storagejanitor.h"
-#include "storage/dbconfig.h"
-#include "storage/datastore.h"
-#include "notificationmanager.h"
-#include "resourcemanager.h"
-#include "tracer.h"
-#include "utils.h"
 #include "debuginterface.h"
-#include "storage/itemretrievalmanager.h"
-#include "storage/collectionstatistics.h"
+#include "intervalcheck.h"
+#include "notificationmanager.h"
 #include "preprocessormanager.h"
+#include "resourcemanager.h"
 #include "search/searchmanager.h"
 #include "search/searchtaskmanager.h"
-#include "aklocalserver.h"
+#include "storage/collectionstatistics.h"
+#include "storage/datastore.h"
+#include "storage/dbconfig.h"
+#include "storage/itemretrievalmanager.h"
+#include "storagejanitor.h"
+#include "tracer.h"
+#include "utils.h"
 
-#include <private/standarddirs_p.h>
-#include <private/protocol_p.h>
 #include <private/dbus_p.h>
 #include <private/instance_p.h>
+#include <private/protocol_p.h>
+#include <private/standarddirs_p.h>
 
-#include <QSqlQuery>
 #include <QSqlError>
+#include <QSqlQuery>
 
 #include <QCoreApplication>
+#include <QDBusServiceWatcher>
 #include <QDir>
 #include <QSettings>
 #include <QTimer>
-#include <QDBusServiceWatcher>
 
 using namespace Akonadi;
 using namespace Akonadi::Server;
 
-namespace {
-
+namespace
+{
 class AkonadiDataStore : public DataStore
 {
     Q_OBJECT
 public:
-    explicit AkonadiDataStore(AkonadiServer &server):
-        DataStore(server)
-    {}
+    explicit AkonadiDataStore(AkonadiServer &server)
+        : DataStore(server)
+    {
+    }
 };
 
 class AkonadiDataStoreFactory : public DataStoreFactory
@@ -60,7 +61,8 @@ class AkonadiDataStoreFactory : public DataStoreFactory
 public:
     explicit AkonadiDataStoreFactory(AkonadiServer &akonadi)
         : m_akonadi(akonadi)
-    {}
+    {
+    }
 
     DataStore *createStore() override
     {
@@ -101,7 +103,6 @@ bool AkonadiServer::init()
         connectionSettings.setValue(QStringLiteral("DBUS/Address"), QLatin1String(dbusAddress));
     }
 
-
     // Setup database
     if (!setupDatabase()) {
         quit();
@@ -114,8 +115,7 @@ bool AkonadiServer::init()
         return false;
     }
 
-    const auto searchManagers = settings.value(QStringLiteral("Search/Manager"),
-                                               QStringList{QStringLiteral("Agent")}).toStringList();
+    const auto searchManagers = settings.value(QStringLiteral("Search/Manager"), QStringList{QStringLiteral("Agent")}).toStringList();
 
     mTracer = std::make_unique<Tracer>();
     mCollectionStats = std::make_unique<CollectionStatistics>();
@@ -137,14 +137,12 @@ bool AkonadiServer::init()
     new ServerAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/Server"), this);
 
-    mControlWatcher = std::make_unique<QDBusServiceWatcher>(
-            DBus::serviceName(DBus::Control), QDBusConnection::sessionBus(),
-            QDBusServiceWatcher::WatchForUnregistration);
-    connect(mControlWatcher.get(), &QDBusServiceWatcher::serviceUnregistered,
-            this, [this]() {
-                qCCritical(AKONADISERVER_LOG) << "Control process died, committing suicide!";
-                quit();
-            });
+    mControlWatcher =
+        std::make_unique<QDBusServiceWatcher>(DBus::serviceName(DBus::Control), QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForUnregistration);
+    connect(mControlWatcher.get(), &QDBusServiceWatcher::serviceUnregistered, this, [this]() {
+        qCCritical(AKONADISERVER_LOG) << "Control process died, committing suicide!";
+        quit();
+    });
 
     // Unhide all the items that are actually hidden.
     // The hidden flag was probably left out after an (abrupt)
@@ -199,7 +197,7 @@ bool AkonadiServer::quit()
         stopDatabaseProcess();
     }
 
-    //QSettings settings(StandardDirs::serverConfigFile(), QSettings::IniFormat);
+    // QSettings settings(StandardDirs::serverConfigFile(), QSettings::IniFormat);
     const QString connectionSettingsFile = StandardDirs::connectionConfigFile(StandardDirs::WriteOnly);
 
     if (!QDir::home().remove(connectionSettingsFile)) {
@@ -223,15 +221,15 @@ void AkonadiServer::newCmdConnection(quintptr socketDescriptor)
     }
 
     auto connection = std::make_unique<Connection>(socketDescriptor, *this);
-    connect(connection.get(), &Connection::disconnected,
-            this, &AkonadiServer::connectionDisconnected);
+    connect(connection.get(), &Connection::disconnected, this, &AkonadiServer::connectionDisconnected);
     mConnections.push_back(std::move(connection));
 }
 
 void AkonadiServer::connectionDisconnected()
 {
-    auto it = std::find_if(mConnections.begin(), mConnections.end(),
-                           [this](const auto &ptr) { return ptr.get() == sender(); });
+    auto it = std::find_if(mConnections.begin(), mConnections.end(), [this](const auto &ptr) {
+        return ptr.get() == sender();
+    });
     Q_ASSERT(it != mConnections.end());
     mConnections.erase(it);
 }
@@ -342,8 +340,7 @@ bool AkonadiServer::createServers(QSettings &settings, QSettings &connectionSett
     mNtfServer = std::make_unique<AkLocalServer>(this);
     // Note: this is a queued connection, as NotificationManager lives in its
     // own thread
-    connect(mNtfServer.get(), QOverload<quintptr>::of(&AkLocalServer::newConnection),
-            mNotificationManager.get(), &NotificationManager::registerConnection);
+    connect(mNtfServer.get(), QOverload<quintptr>::of(&AkLocalServer::newConnection), mNotificationManager.get(), &NotificationManager::registerConnection);
 
     // TODO: share socket setup with client
 #ifdef Q_OS_WIN
@@ -372,12 +369,11 @@ bool AkonadiServer::createServers(QSettings &settings, QSettings &connectionSett
     connectionSettings.setValue(QStringLiteral("Notifications/Method"), QStringLiteral("NamedPipe"));
     connectionSettings.setValue(QStringLiteral("Notifications/NamedPipe"), ntfPipe);
 #else
-    Q_UNUSED(settings);
+    Q_UNUSED(settings)
 
     const QString cmdSocketName = QStringLiteral("akonadiserver-cmd.socket");
     const QString ntfSocketName = QStringLiteral("akonadiserver-ntf.socket");
-    const QString socketDir = Utils::preferredSocketDirectory(StandardDirs::saveDir("data"),
-                                                              qMax(cmdSocketName.length(), ntfSocketName.length()));
+    const QString socketDir = Utils::preferredSocketDirectory(StandardDirs::saveDir("data"), qMax(cmdSocketName.length(), ntfSocketName.length()));
     const QString cmdSocketFile = socketDir % QLatin1Char('/') % cmdSocketName;
     QFile::remove(cmdSocketFile);
     if (!mCmdServer->listen(cmdSocketFile)) {
