@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_AGENTTYPEWIDGET_H
-#define AKONADI_AGENTTYPEWIDGET_H
+#pragma once
 
 #include "akonadiwidgets_export.h"
 
@@ -89,4 +88,3 @@ private:
 
 }
 
-#endif
