@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_COLLECTIONPROPERTIESPAGE_H
-#define AKONADI_COLLECTIONPROPERTIESPAGE_H
+#pragma once
 
 #include "akonadiwidgets_export.h"
 
@@ -209,4 +208,3 @@ private:
 
 }
 
-#endif
