@@ -1,13 +1,13 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
   */
 
 #include "tagselectwidget.h"
 #include "monitor.h"
-#include "tagmodel.h"
 #include "tageditwidget.h"
+#include "tagmodel.h"
 
 #include "shared/akranges.h"
 
@@ -22,18 +22,17 @@ public:
     QScopedPointer<TagEditWidget> mTagEditWidget;
 };
 
-
 TagSelectWidget::TagSelectWidget(QWidget *parent)
-    : QWidget(parent),
-      d(new Private())
+    : QWidget(parent)
+    , d(new Private())
 {
-    QHBoxLayout *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
 
-    auto *monitor = new Monitor(this);
+    auto monitor = new Monitor(this);
     monitor->setObjectName(QStringLiteral("TagSelectWidgetMonitor"));
     monitor->setTypeMonitored(Monitor::Tags);
 
-    auto *model = new TagModel(monitor, this);
+    auto model = new TagModel(monitor, this);
     d->mTagEditWidget.reset(new TagEditWidget());
     d->mTagEditWidget->setModel(model);
     d->mTagEditWidget->setSelectionEnabled(true);
@@ -56,11 +55,16 @@ Tag::List TagSelectWidget::selection() const
 
 QStringList TagSelectWidget::tagToStringList() const
 {
-    return selection() | Views::transform([](const auto &tag) { return tag.url().url(); }) | Actions::toQList;
+    return selection() | Views::transform([](const auto &tag) {
+               return tag.url().url();
+           })
+        | Actions::toQList;
 }
 
 void TagSelectWidget::setSelectionFromStringList(const QStringList &lst)
 {
-    setSelection(lst | Views::transform([](const auto &cat) { return Tag::fromUrl(QUrl{cat}); }) | Actions::toQVector);
+    setSelection(lst | Views::transform([](const auto &cat) {
+                     return Tag::fromUrl(QUrl{cat});
+                 })
+                 | Actions::toQVector);
 }
-
