@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_XML_FORMAT_P_H
-#define AKONADI_XML_FORMAT_P_H
+#pragma once
 
 #include <QString>
 
@@ -87,4 +86,3 @@ inline QString type()
 
 }
 
-#endif
